==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/processing/src/test/java/org/apache/druid/segment/filter/DimensionPredicateFilterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.filter;

import nl.jqno.equalsverifier.EqualsVerifier;
import org.junit.Test;

public class DimensionPredicateFilterTest
{
  @Test
  public void testEqualsContract()
  {
    EqualsVerifier.forClass(DimensionPredicateFilter.class)
                  .withIgnoredFields("predicateFactory")
                  .usingGetClass()
                  .verify();
  }

  @Test
  public void testEqualsContractForDelegatingStringPredicateFactory()
  {
    EqualsVerifier.forClass(DimensionPredicateFilter.DelegatingStringPredicateFactory.class)
                  .withIgnoredFields("baseStringPredicate", "isNullUnknown")
                  .usingGetClass()
                  .verify();
  }
}

==> apache-druid-34.0.0-src.tar.gz: apache-druid-34.0.0-src/processing/src/test/java/org/apache/druid/segment/filter/DimensionPredicateFilterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.filter;

import nl.jqno.equalsverifier.EqualsVerifier;
import org.junit.Test;

public class DimensionPredicateFilterTest
{
  @Test
  public void testEqualsContract()
  {
    EqualsVerifier.forClass(DimensionPredicateFilter.class)
                  .withIgnoredFields("predicateFactory")
                  .usingGetClass()
                  .verify();
  }

  @Test
  public void testEqualsContractForDelegatingStringPredicateFactory()
  {
    EqualsVerifier.forClass(DimensionPredicateFilter.DelegatingStringPredicateFactory.class)
                  .withIgnoredFields("baseStringPredicate")
                  .usingGetClass()
                  .verify();
  }
}
